// sweep-line-cin.cpp
// MCS 481 project 1 description version 1.0
// Modified version of CGAL example 'sweep_line.cpp'
//
// Read segments from stdin, one per line in format:  px py qx qy
//
// Print number of segments read, list of intersection points, and
// total number of intersection points.

#include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
#include <CGAL/Arr_segment_traits_2.h>
#include <CGAL/Sweep_line_2_algorithms.h>
#include <list>

// Use "inexact" kernel for approximate results with floating-point input
typedef CGAL::Exact_predicates_inexact_constructions_kernel Kernel;
typedef Kernel::Point_2                                 Point_2;
typedef CGAL::Arr_segment_traits_2<Kernel>              Traits_2;
typedef Traits_2::Curve_2                               Segment_2;

int main()
{
  CGAL::set_ascii_mode(std::cin);

  // Read the segments from stdin and store them in a list.
  std::list< Segment_2 > segments;
  Point_2 p,q;

  for (std::istream_iterator< Point_2 > i(std::cin);
       i != std::istream_iterator< Point_2 >();
       i++) {
    p = *i; i++; q = *i;
    Segment_2 s(p,q);
    segments.push_back(s);
  }
  std::cout << "Read " << segments.size() << " segments." << std::endl;

  // Compute all intersection points.
  std::list<Point_2>     pts;
  CGAL::compute_intersection_points (segments.begin(), segments.end(),
                                     std::back_inserter (pts));
  
  // Print the result.
  std::cout << "Intersection points: " << std::endl; 
  std::copy (pts.begin(), pts.end(),
             std::ostream_iterator<Point_2>(std::cout, "\n"));

  std::cout << "Total number of intersection points: " << pts.size() << std::endl;

  // The orginal CGAL example does more computations, but we stop here.
  return 0;
}
